==> swc-1.3.37.tar.gz: swc-1.3.37/crates/swc/tests/tsc-references/typeGuardsInFunction.1.normal.js <==
//// [typeGuardsInFunction.ts]
// Note that type guards affect types of variables and parameters only and 
// have no effect on members of objects such as properties. 
// variables in global
var num;
var var1;
// Inside function declaration
function f(param) {
    // global vars in function declaration
    num = typeof var1 === "string" && var1.length; // string
    // variables in function declaration
    var var2;
    num = typeof var2 === "string" && var2.length; // string
    // parameters in function declaration
    num = typeof param === "string" && param.length; // string
}
// local function declaration
function f1(param) {
    var f2 = function f2(param1) {
        // global vars in function declaration
        num = typeof var1 === "string" && var1.length; // string
        // variables from outer function declaration
        num = typeof var2 === "string" && var2.length; // string
        // parameters in outer declaration
        num = typeof param === "string" && param.length; // string
        // local
        var var3;
        num = typeof var3 === "string" && var3.length; // string
        num = typeof param1 === "string" && param1.length; // string
    };
    var var2;
}
// Function expression
function f2(param) {
    // variables in function declaration
    var var2;
    // variables in function expressions
    var r = function(param1) {
        // global vars in function declaration
        num = typeof var1 === "string" && var1.length; // string
        // variables from outer function declaration
        num = typeof var2 === "string" && var2.length; // string
        // parameters in outer declaration
        num = typeof param === "string" && param.length; // string
        // local
        var var3;
        num = typeof var3 === "string" && var3.length; // string
        num = typeof param1 === "string" && param1.length; // string
    }(param);
}
// Arrow expression
function f3(param) {
    // variables in function declaration
    var var2;
    // variables in function expressions
    var r = function(param1) {
        // global vars in function declaration
        num = typeof var1 === "string" && var1.length; // string
        // variables from outer function declaration
        num = typeof var2 === "string" && var2.length; // string
        // parameters in outer declaration
        num = typeof param === "string" && param.length; // string
        // local
        var var3;
        num = typeof var3 === "string" && var3.length; // string
        num = typeof param1 === "string" && param1.length; // string
    }(param);
}
// Return type of function
// Inside function declaration
var strOrNum;
function f4() {
    var var2 = strOrNum;
    return var2;
}
strOrNum = typeof f4() === "string" && f4(); // string | number

==> swc-1.3.97.tar.gz: swc-1.3.97/crates/swc/tests/tsc-references/typeGuardsInFunction.1.normal.js <==
//// [typeGuardsInFunction.ts]
// Note that type guards affect types of variables and parameters only and 
// have no effect on members of objects such as properties. 
// variables in global
var num;
var var1;
// Inside function declaration
function f(param) {
    // global vars in function declaration
    num = typeof var1 === "string" && var1.length; // string
    // variables in function declaration
    var var2;
    num = typeof var2 === "string" && var2.length; // string
    // parameters in function declaration
    num = typeof param === "string" && param.length; // string
}
// local function declaration
function f1(param) {
    var var2;
    function f2(param1) {
        // global vars in function declaration
        num = typeof var1 === "string" && var1.length; // string
        // variables from outer function declaration
        num = typeof var2 === "string" && var2.length; // string
        // parameters in outer declaration
        num = typeof param === "string" && param.length; // string
        // local
        var var3;
        num = typeof var3 === "string" && var3.length; // string
        num = typeof param1 === "string" && param1.length; // string
    }
}
// Function expression
function f2(param) {
    // variables in function declaration
    var var2;
    // variables in function expressions
    var r = function(param1) {
        // global vars in function declaration
        num = typeof var1 === "string" && var1.length; // string
        // variables from outer function declaration
        num = typeof var2 === "string" && var2.length; // string
        // parameters in outer declaration
        num = typeof param === "string" && param.length; // string
        // local
        var var3;
        num = typeof var3 === "string" && var3.length; // string
        num = typeof param1 === "string" && param1.length; // string
    }(param);
}
// Arrow expression
function f3(param) {
    // variables in function declaration
    var var2;
    // variables in function expressions
    var r = function(param1) {
        // global vars in function declaration
        num = typeof var1 === "string" && var1.length; // string
        // variables from outer function declaration
        num = typeof var2 === "string" && var2.length; // string
        // parameters in outer declaration
        num = typeof param === "string" && param.length; // string
        // local
        var var3;
        num = typeof var3 === "string" && var3.length; // string
        num = typeof param1 === "string" && param1.length; // string
    }(param);
}
// Return type of function
// Inside function declaration
var strOrNum;
function f4() {
    var var2 = strOrNum;
    return var2;
}
strOrNum = typeof f4() === "string" && f4(); // string | number
